configure: Files of the Sage distribution that are autogenerated in the bootstrapping phase
===========================================================================================

Description
-----------

This package contains a tar archive of auto-generated files. They are
shipped with Sage in case you do not have a sufficiently recent
autotools version installed.

License
-------

GPLv3+


Upstream Contact
----------------

Automatically generated by Sage, use trac and/or sage-devel for
questions.

Dependencies
------------

None


Special Update/Build Instructions
---------------------------------

This tarball is automatically generated by Sage whenever you run the
$SAGE_ROOT/bootstrap -s or the $SAGE_ROOT/src/bin/sage-update-version
script.
